@@ -102,7 +102,7 @@ class Search(object):
             page = (page - 1) * 10
         else:
             # Implicit seek
-            page = self.adapter.options.start + 10
+            page = self.adapter.start + 10
             
         self._search(start=page)
     
